# ST_LUCAS Python Package

Python package for accessing harmonized space-time aggregated LUCAS
(Land Use and Coverage Area frame Survey) data provided by the
ST_LUCAS system.

<img src="docs/_static/st_lucas_architecture.png" width="650"/><br>
<i>ST_LUCAS system architecture.</i>

Documentation: https://geoforall.fsv.cvut.cz/st_lucas/api/

## Funding

This work has received funding from the European Union's the
Innovation and Networks Executive Agency (INEA) under Grant Agreement
[Connecting Europe Facility (CEF) Telecom project
2018-EU-IA-0095](https://ec.europa.eu/inea/en/connecting-europe-facility/cef-telecom/2018-eu-ia-0095).

<img src="docs/_static/CEF_programme_logo_650px.png" width="650"/>
